@echo off
REM *** Here the number of Threads, your PC can give to the Autoplayer
set /A max_threads=12

REM *** Here the filenames (without .exe ending) of the 4 engines, which 
REM *** the Autoplayer uses for playing. It is recommended, that the
REM *** 4 engines should not differ more than 100 Elo in strength overall,
REM *** better 50-75 Elo, only!!!
REM *** The engine files must be in the same folder as the Autoplayer
REM *** itself.

set Engine1=stockfish_14.1_avx2
set Engine2=stockfish_14_avx2
set Engine3=stockfish_210604_avx2
set Engine4=stockfish_210517_avx2

REM *******************************************************************
REM *** Start of program-code, do not touch ***************************
REM *******************************************************************


cls
@echo *******************************************
@echo ****** Autoplayer Batch Tool V3 by  *******
@echo ****** Stefan Pohl (SPCC)  (C)2021 ********
@echo *******(play games only - version) ********
@echo *******************************************
@echo Name of the pgn-file, which contains the positions, from where the Autoplayer 
@echo should play, without the .pgn file-ending. For each position/line in this 
@echo pgn-file, the Autoplayer will play 12 games:
set /p opening=
@echo Enter the basetime (in seconds) for the games. Thinkingtime for each engine will
@echo be: basetime + 0.5sec increment, which means an estimated gametime of: 
@echo 2*basetime+60 seconds, so if the basetime is 90 seconds, for example, one game
@echo will take around 4 minutes...
set /p basetime=
@echo off

del xxtemp.pgn 2>nul
copy %opening%.pgn xxtemp.pgn > NUL

del results.pgn 2>nul
del ap_variants.pgn 2>nul

REM *** copy the games out of the input-file into a working-file and delete all comments and
REM *** all useless TAGs
pgn-extract --quiet --seven -C -N -V xxtemp.pgn --output results.pgn > NUL

del xxtemp.pgn 2>nul

REM *** Count the number of lines/positions in the opening-file...
for /f "tokens=2,* delims=PGN: " %%G in ('find /C "[White " results.pgn') do set /A anzahl=%%H
if %anzahl% LEQ 0 @echo *** ERROR: No Games found in the file! ***
if %anzahl% LEQ 0 goto error

copy results.pgn ap_variants.pgn > NUL
del results.pgn 2>nul

REM *** Estimate, how long playing the games will take ***
set /A gamesnumber=%anzahl%*12
set /A estimated=%gamesnumber%*(%basetime%*2)
set /A estimated=%estimated%+(60*%gamesnumber%)
set /A estimated=%estimated%/60
set /A est_hours=%estimated%/60
set /A estimated=%estimated%-(%est_hours%*60)

@echo ***************************************************************
@echo *** %anzahl% positions found in the input-file: %gamesnumber% games to play.
@echo *** Estimated time needed in hours/minutes: %est_hours%h %estimated%min
@echo ***************************************************************
@echo off

set /A counter_positions=0
set /A counter_games=0

:loop01
set/A counter_positions=%counter_positions%+1

REM *** use cutechess-cli to play the games ***

REM *** Engine 1 vs. Engine 2
set /A counter_games=%counter_games%+1
@echo *** Playing game %counter_games% of %gamesnumber% 
@echo off
cutechess-cli.exe -engine name="%Engine1%" option.Hash=512 option.Threads=%max_threads% cmd="%Engine1%.exe" proto=uci -engine name="%Engine2%" option.Hash=512 option.Threads=%max_threads% cmd="%Engine2%.exe" proto=uci -pgnout "results.pgn" -event "Autoplayer by Stefan Pohl" -each tc=%basetime%+0.5 timemargin=1000 -resign movecount=3 score=800 -draw movenumber=40 movecount=15 score=19 -recover -concurrency 1 -tournament gauntlet -games 1 -rounds 1 -openings file="ap_variants.pgn" format=pgn order=sequential start=%counter_positions% policy=round > NUL
set /A counter_games=%counter_games%+1
@echo *** Playing game %counter_games% of %gamesnumber%
@echo off
cutechess-cli.exe -engine name="%Engine2%" option.Hash=512 option.Threads=%max_threads% cmd="%Engine2%.exe" proto=uci -engine name="%Engine1%" option.Hash=512 option.Threads=%max_threads% cmd="%Engine1%.exe" proto=uci -pgnout "results.pgn" -event "Autoplayer by Stefan Pohl" -each tc=%basetime%+0.5 timemargin=1000 -resign movecount=3 score=800 -draw movenumber=40 movecount=15 score=19 -recover -concurrency 1 -tournament gauntlet -games 1 -rounds 1 -openings file="ap_variants.pgn" format=pgn order=sequential start=%counter_positions% policy=round > NUL

REM *** Engine 1 vs. Engine 3
set /A counter_games=%counter_games%+1
@echo *** Playing game %counter_games% of %gamesnumber%
@echo off
cutechess-cli.exe -engine name="%Engine1%" option.Hash=512 option.Threads=%max_threads% cmd="%Engine1%.exe" proto=uci -engine name="%Engine3%" option.Hash=512 option.Threads=%max_threads% cmd="%Engine3%.exe" proto=uci -pgnout "results.pgn" -event "Autoplayer by Stefan Pohl" -each tc=%basetime%+0.5 timemargin=1000 -resign movecount=3 score=800 -draw movenumber=40 movecount=15 score=19 -recover -concurrency 1 -tournament gauntlet -games 1 -rounds 1 -openings file="ap_variants.pgn" format=pgn order=sequential start=%counter_positions% policy=round > NUL
set /A counter_games=%counter_games%+1
@echo *** Playing game %counter_games% of %gamesnumber%
@echo off
cutechess-cli.exe -engine name="%Engine3%" option.Hash=512 option.Threads=%max_threads% cmd="%Engine3%.exe" proto=uci -engine name="%Engine1%" option.Hash=512 option.Threads=%max_threads% cmd="%Engine1%.exe" proto=uci -pgnout "results.pgn" -event "Autoplayer by Stefan Pohl" -each tc=%basetime%+0.5 timemargin=1000 -resign movecount=3 score=800 -draw movenumber=40 movecount=15 score=19 -recover -concurrency 1 -tournament gauntlet -games 1 -rounds 1 -openings file="ap_variants.pgn" format=pgn order=sequential start=%counter_positions% policy=round > NUL

REM *** Engine 1 vs. Engine 4
set /A counter_games=%counter_games%+1
@echo *** Playing game %counter_games% of %gamesnumber%
@echo off
cutechess-cli.exe -engine name="%Engine1%" option.Hash=512 option.Threads=%max_threads% cmd="%Engine1%.exe" proto=uci -engine name="%Engine4%" option.Hash=512 option.Threads=%max_threads% cmd="%Engine4%.exe" proto=uci -pgnout "results.pgn" -event "Autoplayer by Stefan Pohl" -each tc=%basetime%+0.5 timemargin=1000 -resign movecount=3 score=800 -draw movenumber=40 movecount=15 score=19 -recover -concurrency 1 -tournament gauntlet -games 1 -rounds 1 -openings file="ap_variants.pgn" format=pgn order=sequential start=%counter_positions% policy=round > NUL
set /A counter_games=%counter_games%+1
@echo *** Playing game %counter_games% of %gamesnumber%
@echo off
cutechess-cli.exe -engine name="%Engine4%" option.Hash=512 option.Threads=%max_threads% cmd="%Engine4%.exe" proto=uci -engine name="%Engine1%" option.Hash=512 option.Threads=%max_threads% cmd="%Engine1%.exe" proto=uci -pgnout "results.pgn" -event "Autoplayer by Stefan Pohl" -each tc=%basetime%+0.5 timemargin=1000 -resign movecount=3 score=800 -draw movenumber=40 movecount=15 score=19 -recover -concurrency 1 -tournament gauntlet -games 1 -rounds 1 -openings file="ap_variants.pgn" format=pgn order=sequential start=%counter_positions% policy=round > NUL

REM *** Engine 2 vs. Engine 3
set /A counter_games=%counter_games%+1
@echo *** Playing game %counter_games% of %gamesnumber%
@echo off
cutechess-cli.exe -engine name="%Engine2%" option.Hash=512 option.Threads=%max_threads% cmd="%Engine2%.exe" proto=uci -engine name="%Engine3%" option.Hash=512 option.Threads=%max_threads% cmd="%Engine3%.exe" proto=uci -pgnout "results.pgn" -event "Autoplayer by Stefan Pohl" -each tc=%basetime%+0.5 timemargin=1000 -resign movecount=3 score=800 -draw movenumber=40 movecount=15 score=19 -recover -concurrency 1 -tournament gauntlet -games 1 -rounds 1 -openings file="ap_variants.pgn" format=pgn order=sequential start=%counter_positions% policy=round > NUL
set /A counter_games=%counter_games%+1
@echo *** Playing game %counter_games% of %gamesnumber%
@echo off
cutechess-cli.exe -engine name="%Engine3%" option.Hash=512 option.Threads=%max_threads% cmd="%Engine3%.exe" proto=uci -engine name="%Engine2%" option.Hash=512 option.Threads=%max_threads% cmd="%Engine2%.exe" proto=uci -pgnout "results.pgn" -event "Autoplayer by Stefan Pohl" -each tc=%basetime%+0.5 timemargin=1000 -resign movecount=3 score=800 -draw movenumber=40 movecount=15 score=19 -recover -concurrency 1 -tournament gauntlet -games 1 -rounds 1 -openings file="ap_variants.pgn" format=pgn order=sequential start=%counter_positions% policy=round > NUL

REM *** Engine 2 vs. Engine 4
set /A counter_games=%counter_games%+1
@echo *** Playing game %counter_games% of %gamesnumber%
@echo off
cutechess-cli.exe -engine name="%Engine2%" option.Hash=512 option.Threads=%max_threads% cmd="%Engine2%.exe" proto=uci -engine name="%Engine4%" option.Hash=512 option.Threads=%max_threads% cmd="%Engine4%.exe" proto=uci -pgnout "results.pgn" -event "Autoplayer by Stefan Pohl" -each tc=%basetime%+0.5 timemargin=1000 -resign movecount=3 score=800 -draw movenumber=40 movecount=15 score=19 -recover -concurrency 1 -tournament gauntlet -games 1 -rounds 1 -openings file="ap_variants.pgn" format=pgn order=sequential start=%counter_positions% policy=round > NUL
set /A counter_games=%counter_games%+1
@echo *** Playing game %counter_games% of %gamesnumber%
@echo off
cutechess-cli.exe -engine name="%Engine4%" option.Hash=512 option.Threads=%max_threads% cmd="%Engine4%.exe" proto=uci -engine name="%Engine2%" option.Hash=512 option.Threads=%max_threads% cmd="%Engine2%.exe" proto=uci -pgnout "results.pgn" -event "Autoplayer by Stefan Pohl" -each tc=%basetime%+0.5 timemargin=1000 -resign movecount=3 score=800 -draw movenumber=40 movecount=15 score=19 -recover -concurrency 1 -tournament gauntlet -games 1 -rounds 1 -openings file="ap_variants.pgn" format=pgn order=sequential start=%counter_positions% policy=round > NUL

REM *** Engine 3 vs. Engine 4
set /A counter_games=%counter_games%+1
@echo *** Playing game %counter_games% of %gamesnumber%
@echo off
cutechess-cli.exe -engine name="%Engine3%" option.Hash=512 option.Threads=%max_threads% cmd="%Engine3%.exe" proto=uci -engine name="%Engine4%" option.Hash=512 option.Threads=%max_threads% cmd="%Engine4%.exe" proto=uci -pgnout "results.pgn" -event "Autoplayer by Stefan Pohl" -each tc=%basetime%+0.5 timemargin=1000 -resign movecount=3 score=800 -draw movenumber=40 movecount=15 score=19 -recover -concurrency 1 -tournament gauntlet -games 1 -rounds 1 -openings file="ap_variants.pgn" format=pgn order=sequential start=%counter_positions% policy=round > NUL
set /A counter_games=%counter_games%+1
@echo *** Playing game %counter_games% of %gamesnumber%
@echo off
cutechess-cli.exe -engine name="%Engine4%" option.Hash=512 option.Threads=%max_threads% cmd="%Engine4%.exe" proto=uci -engine name="%Engine3%" option.Hash=512 option.Threads=%max_threads% cmd="%Engine3%.exe" proto=uci -pgnout "results.pgn" -event "Autoplayer by Stefan Pohl" -each tc=%basetime%+0.5 timemargin=1000 -resign movecount=3 score=800 -draw movenumber=40 movecount=15 score=19 -recover -concurrency 1 -tournament gauntlet -games 1 -rounds 1 -openings file="ap_variants.pgn" format=pgn order=sequential start=%counter_positions% policy=round > NUL

REM *** All positions played? Then exit, otherwise jump back and play next position.
if %counter_positions% GEQ %anzahl% goto ende
goto loop01
:ende
del ap_variants.pgn 2>nul

@echo ***********************************
@echo ******* Autoplay finished *********
@echo *** Played games in results.pgn ***
@echo ***********************************
@echo off
:error
REM *** make noise and wait for a pressed key ***
CALL playwav %windir%/media/alarm02.wav
@pause



